<img alt="logo" height="40%" src="_media/icon.svg" width="40%" class="logo"/>

This documentation is generated automatically from the available plugins and their operations.

To build documentation for your own project, use the `tenrec docs` command!